@@ -8,23 +8,18 @@
 #include <string.h>
 
 #include "sysinfo.h"
-#include "generic.h"
+#include "include/generic.h"
 
 #define SIZE(x) sizeof(x)/sizeof(x[0])
 
 extern float external_bogomips(void);
 
-int get_cpu_info(cpu_info_t *cpu_info) {
+int get_cpu_info(struct cpu_info_type *cpu_info) {
 
    int val_int;
    int val_len;
-   
-/*   char bogomips_total[BUFSIZ]="???";
-   char bogo_total[BUFSIZ];
-   
-   struct utsname buf;
-*/
-   char val_str[100];
+
+   char val_str[BUFSIZ];
 
    int ctl_cpu[] = { CTL_HW, HW_MODEL };
    int ctl_ncpu[] = { CTL_HW, HW_NCPU };
@@ -33,7 +28,7 @@ int get_cpu_info(cpu_info_t *cpu_info) {
    if (sysctl(ctl_cpu, SIZE(ctl_cpu), val_str, &val_len,0,0))
      perror("sysctl");
    else
-     strncpy(cpu_info->chip_type,val_str,63);
+     strncpy(cpu_info->chip_type,val_str,SYSINFO_CHIP_TYPE_SIZE);
    
    val_len = sizeof(val_int);   
    if (sysctl(ctl_ncpu, SIZE(ctl_ncpu), &val_int, &val_len,0,0))
@@ -48,5 +43,3 @@ int get_cpu_info(cpu_info_t *cpu_info) {
    return 0;
    
 }
-      
-
