@@ -56,7 +56,7 @@ int get_hardware(char *hardware_string) {
 }
 
     /* Some architectures might have better ways of detecting RAM size */
-long int get_arch_specific_mem_size(void) {
+long long get_arch_specific_mem_size(void) {
        /* We have no special way of detecting RAM */
-       return -1;
+       return 0;
 }
