@@ -176,14 +176,24 @@ int get_cpu_info(struct cpu_info_type *cpu_info) {
        
           /* Phenom */
        if (strstr(model_string,"Phenom")!=NULL) {
-	  strncpy(cpu_info->chip_type,"Phenom",7);
-       }       
+	  if (strstr(model_string,"II")!=NULL) {
+	     strncpy(cpu_info->chip_type,"Phenom II",10);
+	  }
+	  else {
+	     strncpy(cpu_info->chip_type,"Phenom",7);
+	  }
+       }
        
           /* Geode */
        if ( strstr(model_string,"Geode")!=NULL) {
 	  strncpy(cpu_info->chip_type,"Geode",6);
        }
        
+          /* Handle BIOS/kernel too old issue */
+       if ( strstr(model_string,"unknown")!=NULL) {
+	  strncpy(cpu_info->chip_type,"Unknown",8);
+       }
+       
           /* Work around old kernels */
        if (model_string[0]==0) {
 	  if (plain_model[0]=='9') {
@@ -201,6 +211,17 @@ int get_cpu_info(struct cpu_info_type *cpu_info) {
                   /* should catch the common case                  */
        strncpy(cpu_info->chip_vendor,"Centaur",8);
        
+       /* Should this be generic?  We should never print processor twice */
+       {
+	  char *processor_begin;
+          processor_begin=strstr(model_string," Processor");
+	  if (processor_begin!=NULL) {
+	     /* I hate to use pointer math */
+	    model_string[(processor_begin-model_string)]='\0';
+	  }
+       }
+
+   
           /* Is this the proper thing to do?  It looks silly */
           /* calling them "Centaur VIA" chips                */
        if (strstr(model_string,"VIA")!=NULL) {
@@ -227,10 +248,11 @@ int get_cpu_info(struct cpu_info_type *cpu_info) {
        if ( strstr(model_string,"Geode")!=NULL)
 	  strncpy(cpu_info->chip_type,"Geode",6);
        
-       if ( !(strncmp(model_string,"6x86L",5)))
+       if ( !(strncmp(model_string,"6x86",4)))
 	  strncpy(cpu_info->chip_type,"6x86",5);
        if ( !(strncmp(model_string,"6x86M",5)))
-	  strncpy(cpu_info->chip_type,"6x86MMX",8); 
+	  strncpy(cpu_info->chip_type,"6x86MMX",8);
+       
        if ( !(strncmp(model_string,"M III",5))) 
 	  strncpy(cpu_info->chip_type,"MIII",5);
        else if ( !(strncmp(model_string,"M II",4))) 
@@ -324,7 +346,16 @@ int get_cpu_info(struct cpu_info_type *cpu_info) {
 	      ) {
 	     strncpy(cpu_info->chip_type,"Pentium Xeon",16);
           }
-
+	     /* Nehalem */
+          if (strstr(model_string,"Core(TM) i7")!=NULL) {
+	     strncpy(cpu_info->chip_type,"i7",3);
+	  }
+          if (strstr(model_string,"Core(TM) i5")!=NULL) {
+	     strncpy(cpu_info->chip_type,"i5",3);
+	  }
+          if (strstr(model_string,"Core(TM) i3")!=NULL) {
+	     strncpy(cpu_info->chip_type,"i3",3);
+	  }
 	     /* Core and Core2 */
 	  if (strstr(model_string,"Core(TM)2 Duo")!=NULL) {
 	     strncpy(cpu_info->chip_type,"Core2 Duo",10);
@@ -358,6 +389,11 @@ int get_cpu_info(struct cpu_info_type *cpu_info) {
        if (!strncmp(model_string,"00/07",5)) {
 	  strncpy(cpu_info->chip_type,"Pentium III",12);
        }
+          
+          /* Virtual Machines simulated by QEMU */
+       if (strstr(model_string,"QEMU")!=NULL) {
+	  strncpy(cpu_info->chip_type,"QEMU Virtual",13);
+       }
     }
    
        /* ************* */
@@ -381,6 +417,18 @@ int get_cpu_info(struct cpu_info_type *cpu_info) {
     if ( !(strncmp(vendor_string,"RiseRiseRise",12))) {
        strncpy(cpu_info->chip_vendor,"Rise",5);
     }
+
+       /* ************** */
+       /* SiS            */
+       /* ************** */
+    if ( !(strncmp(vendor_string,"SiS SiS SiS",11))) {
+       strncpy(cpu_info->chip_vendor,"SiS",4);
+       if (family!=0) {
+	  sprintf(temp_string,"%i86",family);
+          strncpy(cpu_info->chip_type,temp_string,4);
+       }
+    }
+
    
        /* ************* */
        /* Transmeta     */
@@ -404,6 +452,17 @@ int get_cpu_info(struct cpu_info_type *cpu_info) {
 	  strncpy(cpu_info->chip_type,"486SX",6);
        }
     }
+
+       /* ************** */
+       /* Vortex         */
+       /* ************** */
+    if ( !(strncmp(vendor_string,"Vortex86 SoC",11))) {
+       strncpy(cpu_info->chip_vendor,"Vortex",7);
+       if (family!=0) {
+	  sprintf(temp_string,"%i86",family);
+          strncpy(cpu_info->chip_type,temp_string,4);
+       }
+    }
    
        /* ****************************** */
        /* Try to handle cpus w/o cpuinfo */
@@ -444,7 +503,7 @@ int get_hardware_info(char *hardware_string) {
 }
 
     /* Some architectures might have better ways of detecting RAM size */
-long int get_arch_specific_mem_size(void) {
+long long get_arch_specific_mem_size(void) {
     /* We have no special way of detecting RAM */
-    return -1;
+    return 0;
 }
